Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2866)

Unified Diff: chrome/browser/chromeos/policy/enrollment_handler_chromeos.h

Issue 2677563005: Chromad: Use DM server reply to determine enrollment type (Closed)
Patch Set: Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/policy/enrollment_handler_chromeos.h
diff --git a/chrome/browser/chromeos/policy/enrollment_handler_chromeos.h b/chrome/browser/chromeos/policy/enrollment_handler_chromeos.h
index 6966101871332f50f9b3aff7da3ab1c86d4670a4..b767821d68f461fef6a1cf2fe23c50a952c544ea 100644
--- a/chrome/browser/chromeos/policy/enrollment_handler_chromeos.h
+++ b/chrome/browser/chromeos/policy/enrollment_handler_chromeos.h
@@ -111,12 +111,13 @@ class EnrollmentHandlerChromeOS : public CloudPolicyClient::Observer,
STEP_VALIDATION = 5, // Policy validation.
STEP_ROBOT_AUTH_FETCH = 6, // Fetching device API auth code.
STEP_ROBOT_AUTH_REFRESH = 7, // Fetching device API refresh token.
- STEP_LOCK_DEVICE = 8, // Writing installation-time attributes.
- STEP_STORE_TOKEN = 9, // Encrypting and storing DM token.
- STEP_STORE_ROBOT_AUTH = 10, // Encrypting & writing robot refresh token.
- STEP_STORE_POLICY = 11, // Storing policy and API refresh token. For
+ STEP_AD_DOMAIN_JOIN = 8, // Joining Active Directory domain.
+ STEP_LOCK_DEVICE = 9, // Writing installation-time attributes.
+ STEP_STORE_TOKEN = 10, // Encrypting and storing DM token.
+ STEP_STORE_ROBOT_AUTH = 11, // Encrypting & writing robot refresh token.
+ STEP_STORE_POLICY = 12, // Storing policy and API refresh token. For
// AD, includes policy fetch via authpolicyd.
- STEP_FINISHED = 12, // Enrollment process done, no further action.
+ STEP_FINISHED = 13, // Enrollment process done, no further action.
};
// Handles the response to a request for server-backed state keys.
@@ -137,6 +138,13 @@ class EnrollmentHandlerChromeOS : public CloudPolicyClient::Observer,
// successful.
void HandlePolicyValidationResult(DeviceCloudPolicyValidator* validator);
+ // Start joining to Active Directory domain in case device is enrolling into
achuithb 2017/02/07 20:27:17 Start joining the Active Directory domain in case
Roman Sorokin (ftl) 2017/02/10 14:57:10 Done.
+ // Active Directory management mode.
+ void StartJoinAdDomain();
+
+ // Handles successful Active Directory domain join.
+ void OnAdDomainJoined(std::string realm);
achuithb 2017/02/07 20:27:16 const std::string&
Roman Sorokin (ftl) 2017/02/10 14:57:10 Done.
+
// Calls InstallAttributes::LockDevice() for enterprise enrollment and
// DeviceSettingsService::SetManagementSettings() for consumer
// enrollment.
@@ -200,6 +208,7 @@ class EnrollmentHandlerChromeOS : public CloudPolicyClient::Observer,
// The validated policy response info to be installed in the store.
std::unique_ptr<enterprise_management::PolicyFetchResponse> policy_;
std::string domain_;
+ std::string realm_;
std::string device_id_;
// Current enrollment step.

Powered by Google App Engine
This is Rietveld 408576698